#
# spec file for package foliate
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define oname com.github.johnfactotum.Foliate
Name:           foliate
Version:        3.3.0
Release:        1.1
Summary:        A GTK eBook reader
License:        GPL-3.0-only
Group:          Productivity/Office/Other
URL:            https://johnfactotum.github.io/foliate/
Source:         %{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE foliate-fix-export-of-incorrect-dep-Adw.patch -- Dependencies are not exported correctly
Patch0:         foliate-fix-export-of-incorrect-dep-Adw.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gjs-1.0) >= 1.76
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk4) >= 4.12
BuildRequires:  pkgconfig(libadwaita-1) >= 1.7
BuildRequires:  pkgconfig(webkitgtk-6.0) >= 2.40.1
Requires:       gjs
BuildArch:      noarch

%description
A GTK eBook viewer, built with GJS and Epub.js.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

chmod a-x README.md COPYING
find %{buildroot}/%{_datadir} -type f -executable -exec chmod -x "{}" +
%fdupes %{buildroot}/%{_datadir}/%{oname}

%find_lang %{oname} --with-gnome

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{oname}.desktop
%{_datadir}/%{oname}
%{_datadir}/glib-2.0/schemas/
%{_datadir}/metainfo/%{oname}.metainfo.xml
%{_datadir}/icons/hicolor/*/apps/*

%files lang -f %{oname}.lang

%changelog
* Tue Apr  1 2025 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 3.3.0:
  * Added support for mouse forward/backward buttons.
  * Improved text wrapping in headings.
  * Improved default link style.
* Fri Dec 20 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 3.2.1:
  * Fixed tables not displayed in FB2 books.
  * Updated translations.
* Thu Nov 28 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 3.2.0:
  * Revamped translation tool, which now remembers the last target
    language, and allows filtering languages
  * Improved PDF support: the rendering is faster and no longer
    blurry
  * Improved rendering of fixed layout EPUBs (see comments in #1318)
  * Improved focus handling: the focus is no longer lost when
    navigating to new sections, and tabbing no longer breaks layout
  * Improved text selection across pages, allowing selecting
    to the previous page
  * It now only shows more than one column when the viewport is in
    landscape (or, for vertical writing, in portrait)
  * Changed shortcut for the table of contents from Ctrl+Alt+T
    to Ctrl+T.
  * Added Space/Shift+Space shortcuts for turning pages.
  * Added option to open books with external application from
    the library view.
  * Fixed formatting of copied text.
  * Fixed extra border in CBZ files.
  * Fixed handling of bare search template URL in OPDS feeds.
* Thu Apr  4 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 3.1.1:
  * Fixed end of chapter cut off when chapter starts with page
    break.
  * Fixed incorrect text wrapping in tables.
  * Fixed a performance issue with OPDS catalogs.
* Sat Jan  6 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 3.1.0:
  * Added support for OPDS catalogs, now with support for OPDS 2.0.
  * Added option to override publisher font.
  * Added option to reduce animation.
  * Added support for JPEG XL in CBZ.
  * Fixed parsing of non-year-only first-century and BCE dates.
* Mon Nov 20 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 3.0.1:
  * Updated translations.
  * Fixed desktop entry and AppData.
  * Fixed broken layout for some books.
  * Fixed chromatic abberation in invert mode.
  * Fixed sidebar background (pictured).
* Fri Nov 17 2023 Dead Mozay <dead_mozay@opensuse.org>
- Fixed export of incorrect dependencies 'typelib(Adw)})'.
  Patch added foliate-fix-export-of-incorrect-dep-Adw.patch.
* Fri Nov 17 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 3.0.0
  * UI changes:
  - The library and the e-book viewer are unified in a single
    window.
  - The library now loads more books as you scroll, no longer
    requiring clicks to load more items.
  - Table of contents, annotations, bookmarks are now in a sidebar,
    which is docked to the side by default, but can also be set
    to be always folded (overlaid on top of content when revealed).
  - The "Add Bookmark" button is moved to the header bar,
    and the page will show a ribbon when bookmarked.
  - Removed "turn page on tap"; use swiping instead.
  - Removed option for skeuomorphic shadows.
  - Removed experimental traditional titlebar option.
  * Book rendering:
  - It no longer loads the entire file into memory,
    greatly reducing startup time and memory usage,
    and it no longer loads every item in the TOC,
    further improving startup time.
  - Reloading now properly reloads the file, rather than merely
    re-rendering.
  - Mobipocket and Kindle files are no longer extracted on disk;
    they are processed entirely in memory.
  - Mobipocket files are now divided into sections at
    <mbp:pagebreak> tags, which greatly improves performance
    as it no longer requires rendering the whole book at once.
    Unfortunately this also means existing annotations for
    this format will not be displayed correctly.
  - When a page is not valid XHTML, it will be processed as HTML.
  - It no longer tries to override fonts with CSS. Instead,
    you can now configure the default serif, sans-serif,
    and monospace fonts, as well as setting the minimum font size.
  - Added support for obfuscated fonts.
  - Added support for user stylesheet.
  - FB2: fixed infinite recursion bug (#935) and comments
    are now correctly ignored.
  - Added experimental support for PDF files.
  - Removed support for CBR, CBT, and CB7 files
    (CBZ is still supported).
  * Layout:
  - Paginated mode now has animation and 1:1 touchscreen
    and touchpad swipe gestures.
  - Paginated mode supports more than two columns.
    The number of columns is controlled by a maximum width
    setting. As the window gets wider, it will add more columns
    to prevent lines from getting too long.
  - Margins are now relative to the viewport size.
  - It is now possible to configure both max width and max height.
  - The page reflows faster when resizing, and reliably stays
    at the same location without flashing.
  - Switching between paginated and scrolled layouts is faster
    and can be done with a shortcut (Ctrl+M).
  - Removed continuous scrolling mode, as the new renderer does
    not support it (yet).
  * Locations:
  - Locations are now calculated from raw byte size instead
    of character count. The progress slider and reading time
    estimates are available instantly when you first open a book,
    and locations are no longer cached. Old .json files in the
    cache directory can be deleted.
  - The progress slider now turns pages as you drag,
    and can be used with keyboard and mouse wheel.
  - Page-list and landmarks are now supported and can be
    accessed from the location popover.
  * Find in book:
  - Results are now shown in the sidebar.
  - Added option to ignore diacritics and to match whole words only.
  - Added shortcuts for going to next and previous matches
    (Ctrl+G and Ctrl+Shift+G).
  * Image viewer:
  - Images are opened with double click by default;
    removed options for single, right, and middle click.
  - Images are now copied and saved in their original format
    (previously, they were always converted to PNG).
  * Narration:
  - Text-to-speech now uses Speech Dispatcher,
    and supports pausing, skipping, word highlighting,
    SSML, and speed and pitch controls.
  - Added support for EPUB Media Overlays.
  * Copying:
  - Selected text can now be copied with HTML formatting.
  - Added "Copy with Citation", which adds the author and title
    info to the copied text.
  - Added "Copy Identifier", which copies the CFI of
    the text fragment.
  * Security:
  - The WebView no longer has unlimited file access.
  * Other changes:
  - Added underline option for annotations.
  - Annotations are now saved with timestamps.
  - Added the ability to print chapters and selections.
  - WebKit's inspector is always enabled, and can be accessed
    from the menu, or by pressing F12.
  * Added BuildRequires:
  - gtk4
  - libadwaita
  - webkitgtk-6.0
  - desktop-file-utils
* Fri Jan 14 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop hard typelib(WebKit2) Requires: No longer needed, now
  autodetected.
* Thu Jan 13 2022 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 2.6.4:
  * Fixed various bugs.
  * Remove foliate-WebKit-version.patch: Patch in the release.
* Fri Nov 12 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add foliate-WebKit-version.patch: Fix launch if WebKit2-5.0
  happens to be installed (boo#1192627).
* Thu Oct 14 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Filter out the optional tracker typelib Requires.
* Fri Jun 18 2021 QK ZHU <qkzhu@suse.com>
- Fixed gjs dependency issue (boo#1187328).
* Mon May 10 2021 Dirk Müller <dmueller@suse.com>
- stop owning directories provided by filesystem rpm (bsc#1184786)
* Thu Apr  1 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.6.3:
  * Fixed a performance issue with zipped files (including EPUB files)
* Thu Mar 25 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.6.2:
  * Fix UI when running with libhandy 1.x
* Wed Mar 24 2021 Dead Mozay <dead_mozay@opensuse.org>
- Remove 2c28932c6266cbeddbe49d7aa6ca8d70d125e96f.patch
  Included in release 2.6.0.
* Wed Mar 24 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.6.1:
  * Fixed automatic layout.
* Wed Mar 24 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.6.0:
  * Added support for opening HTML files.
  * Consistent inner and outer margins.
  * The automatic layout no longer supports 4 columns.
  * Fixed long words overflowing.
  * Fixed custom themes not saved across sessions.
  * Fixed shortcuts for key pads.
  * Fixed opening non-UTF-8 zipped FB2 files.
  * Fixed books not opening on GNOME 40.
* Sun Mar 21 2021 Marcus Rueckert <mrueckert@suse.de>
- Added https://github.com/johnfactotum/foliate/commit/2c28932c6266cbeddbe49d7aa6ca8d70d125e96f.patch
  Make foliate work with GNOME 40 (gh:johnfactotum/foliate#689)
* Fri Nov 27 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Change filter typelib(Handy) = 1 to exclude now obsolete version
  0.0 instead of current version 1.
* Thu Oct 15 2020 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 2.5.0:
  * Improved support for touch screen.
  * OPDS credentials can now be remembered.
  * Various fixes for GNOME 3.38.
  * Fixed Wiktionary internal links.
  * Added Basque, Korean, and Norwegian translations
* Mon Jul  6 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.4.2:
  * Fixed unable to open some EPUB files
* Mon Jul  6 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.4.1:
  * Fixed unable to open Mobipocket files
* Thu Jul  2 2020 Scott Young <dev@iotib.net>
- Fixed dependency issue
- Added symlink "foliate" targetting main binary.
* Thu Jul  2 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.4.0:
  * Improved metadata display
  * Improved FictionBook rendering
  * Improved UI for acquiring books from OPDS (#404, #405)
  * Fixed unique identifier extraction for EPUB files
  * Fixed missing window icon (#456)
  * Fixed eSpeak NG voice not selected when testing TTS
    configuration
* Fri Jun 19 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.3.0:
  * OPDS catalogs:
  - Catalogs are now opened in the main library window (#403)
  - View current location
  - Go to catalog start page
  - Reload catalog
  - Add current feed to catalogs
  - HTTP authentication support (#421)
  * Other changes:
  - Fixed unique identifier extraction for
    FictionBook (.fb2, .fb2.zip) files (#462)
  - Fixed newlines being ignored when copying text (#463)
  - “Turn page on tap” is now disabled in
    non-paginated layouts (#464)
  - Opening a book from the library view now closes the
    library window (#446)
  - Language and publication dates in metadata are now parsed
    and formatted
  - Export annotations from the library view
* Thu Jun 11 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Filter "typelib(Handy) = 1" dependency. We use handy 0.0.
* Tue Jun  9 2020 Jan Engelhardt <jengelh@inai.de>
- Trim bias from descriptions.
- Simplify %%install commands.
* Sun Jun  7 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.2.1:
  * Fixed blurry book covers on HiDPI
  * Fixed OPDS links to Standard Ebooks and Project Gutenberg
  * Fixed wrong view icon on startup
* Fri May 29 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 2.2.0:
  * Library:
  - A library view showing recent books and reading progress
  - Search books by metadata
  - E-book discovery with OPDS
  * New supported formats:
  - FictionBook (.fb2, .fb2.zip) (#128)
  - Comic book archive (.cbr, .cbz, .cbt, .cb7)
  - Plain text (.txt) (#226)
  - Unpacked EPUB files
  * Layout:
  - Option to set maximum page width
  - The "Automatic" layout will now show four columns
    when the page width is wide
  * Image viewer:
  - Improved image viewer, with new shortcuts and the ability
    to rotate and invert images
  - Option to disable image viewer, or to open images on double,
    middle, or right click
  * Text-to-speech:
  - Improved text-to-speech configuration UI
  - Ability to set text-to-speech voice based on book language
  * Annotations
  - Import annotations from JSON
  - Search in annotations
  - Annotations are now sorted in the same order as they appear
    in the book
  * Security:
  - "Allow Unsafe Content" now only enables JavaScript; external
    content will no longer be loaded. This is an important
    security fix. If you are running an old version of Foliate
    and cannot upgrade, you should disable
    "Allow Unsafe Content".
  - WebKit processes are now sandboxed
  * Other featues and fixes:
  - Improved support for vertical and right-to-left books
  - Support for StarDict dictionaries
  - Fixed current location not preserved when resizing
  - Fixed auto-hiding header bar under some themes
  - Command-line options for showing version and adding books
    to library
  - Option to clear or disable cache
  - When an HTML page contains invalid self-closing anchor tags,
    it is now parsed as XHTML
- Add fdupes BuildRequires and macro call, remove duplicate files.
* Thu Apr  9 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 2.1.1:
  * Fixed wrong version number.
* Wed Apr  8 2020 idonmez@suse.com
- Update to version 2.1.0:
  * New and improved icon
  * Option to disable turn page on tap
  * A menu on the welcome screen for opening recent files
  * Restored shortcuts for showing ToC, annotations, and bookmarks
  * Fixed application not translated.
* Sun Apr  5 2020 bjorn.lie@gmail.com
- Update to version 2.0.0:
  * New stable branch, various interface improvments and bug fixes.
* Wed Dec  4 2019 bjorn.lie@gmail.com
- Update to version 1.5.3+54:
  * Right align doesn't work well with tables
  * Update package info
  * Update Indonesian translation (#182)
  * Fix glyph clipping in WebKit (#179)
  * Set WebKit default font size
  * Flatpak: prevent X11 access in Wayland
  * Remove unnecessary global variables for TTS, footnotes, images
  * Initial change to WebKitUserContentManager for messaging
  * Add copy to selection options (#172)
  * Set vendored code for Linguist
  * Updated Dutch (Netherlands) translation (#169)
  * Add link to wiki in README.md
  * Update French translation (#163)
  * Fix unable to add bookmark when section not found
  * Fix stuff not escaped for Pango markup
  * Move constant out of the loop
  * Show author in headerbar
  * Fallback when unable to get section
  * Show chapter name in bookmarks list
  * Update Brazilian Portuguese translation (#160)
  * Fix wrong Wiktionary link when looking up again due to capitalization
  * Fix Wikipedia lookup broken after previous commit
  * Make internal links work in footnote popover
  * Make TTS available for selection
  * Fix wrong popover position in continous scrolling mode
  * Make navbar buttons flat
  * Temporary fix for invisible popovers due to wrong position values
  * Fix internal link broken when popup footnote is disabled
  * Add continuous scrolling option
  * Support getting current chapter for TOC items with anchors
  * Update translations
  * Improve HTML to Pango markup conversion
  * Don't push to history if the location doesn't change
  * Fix empty state padding
  * Suppress promise rejection warnings
  * Change "chapter" to "section"
  * Add option to go to CFI
  * Extract code for getting popover position to a function
  * Move util functions forward and main functions to the end
  * Add some comments
  * Move wheel and keyboard event code to more sensible location
  * Make it possible to select across pages
  * Fix pt_BR.po
  * Update Brazilian Portuguese translation (#153)
  * Lint assets
  * Lint main.js
  * Cleanup HTML and txt export code
  * Fix ampersand troubles
  * Use markup for Wikipedia extract
  * Fix soft hyphens confusing Festival
  * Add translation info to AppData
  * Update French translation (#151)
  * Update Dutch translation (#150)
  * Update README.md
* Thu Nov 28 2019 bjorn.lie@gmail.com
- Update _service file to point to explicit tag upstream, not
  git-master.
* Tue Sep  3 2019 dead_mozay@opensuse.org
- Update to version 1.5.3:
  * Fix stuff not escaped for Pango markup
  * Move constant out of the loop
  * Show author in headerbar
  * Fallback when unable to get section
  * Show chapter name in bookmarks list
  * Update Brazilian Portuguese translation (#160)
  * Fix wrong Wiktionary link when looking up again due to capitalization
  * Fix Wikipedia lookup broken after previous commit
  * Make internal links work in footnote popover
  * Make TTS available for selection
  * Fix wrong popover position in continous scrolling mode
  * Make navbar buttons flat
  * Temporary fix for invisible popovers due to wrong position values
  * Fix internal link broken when popup footnote is disabled
  * Add continuous scrolling option
  * Support getting current chapter for TOC items with anchors
  * Update translations
  * Improve HTML to Pango markup conversion
  * Don't push to history if the location doesn't change
  * Fix empty state padding
  * Suppress promise rejection warnings
  * Change "chapter" to "section"
  * Add option to go to CFI
  * Extract code for getting popover position to a function
  * Move util functions forward and main functions to the end
  * Add some comments
  * Move wheel and keyboard event code to more sensible location
  * Make it possible to select across pages
  * Fix pt_BR.po
  * Update Brazilian Portuguese translation (#153)
  * Lint assets
  * Lint main.js
  * Cleanup HTML and txt export code
  * Fix ampersand troubles
  * Use markup for Wikipedia extract
  * Fix soft hyphens confusing Festival
  * Add translation info to AppData
  * Update French translation (#151)
  * Update Dutch translation (#150)
  * Update README.md
  * Update translations
  * Improve HTML to Pango markup conversion
  * Update screenshots
  * Use GtkLabel instead of WebView to display book description
  * Improve HTML to Pango markup conversion
  * Handle invalid cover image
  * Fix utils.js not included when CSP is disabled
  * Enable popover footnote by default
  * Add BibTeX export support (#130)
  * Make it possible to lookup Wikipedia when clicking on "Lookup"
  * Offer to search on Wiktionary when entry not found
  * Fix Python not found in Flatpak
  * Revert label change
  * Use markup for footnote popover
  * Fix soft hyphen and word joiner causing lookup to fail
  * Refactor lookup
  * Improve footnote extraction
  * Fix about dialog not closing when the close button is clicked
  * Improve footnote extraction
  * Update translations
  * Fix typo
  * Update Brazilian Portuguese translation (#144)
* Fri Jul 19 2019 dead_mozay@opensuse.org
- Update to version 1.5.2:
  * Fix temporary directory not being removed on close
  * Fix not being able to get image when src isn't a blob URL
  * Fix TOC navigation not working with some books
  * Update Russian translation
  * Specify input type instead of letting Epub.js guess
* Thu Jul 18 2019 dead_mozay@opensuse.org
- Update to version 1.5.1:
  * Fix debian dependencies
  * Fix ToC shortcut
  * Update Brazilian Portuguese translation (#138)
  * Update Dutch translation (#135)
  * Update French translation (#132)
  * Update Russian translation (#131)
* Sun Jul 14 2019 Dead Mozay <dead-mozay@opensuse.org>
- Fix rpmlint error
* Sun Jul 14 2019 dead_mozay@opensuse.org
- Update to version 1.5.0:
  * Update translations
  * Update README.md
  * Add .mobi and .azw support with KindleUnpack
  * Some cleanup
  * Handle situation where there are no annotations
  * Use book language for Wikipedia
  * Add support for exporting annotations to HTML and plain text
  * Add JSON export
  * Stop TTS when tts-command is changed
  * Update README.md
  * Add shortcut for TTS
  * Add shortcuts to popovers that don't have shortcuts
  * Fix typo
  * Improve TTS UI
  * Use tts-command value to determine whether or not to show TTS menu items
  * Stop reading at the end of the book
  * Make TTS command configurable
  * Better way to check and use flatpak-spawn
  * Replace "smart" punctuation because Festival doesn't understand them
  * Stop TTS when window is closed
  * Only show TTS menu items when Festival is detected
  * Fix `reject()` not called
  * Use SIGINT instead of SIGTERM to stop speaking
  * Add basic Text-to-Speech support with Festival
  * Update Dutch (Netherlands) translation (#121)
  * Fix IndexSizeError
  * Build instruction fixes in README.md
  * Add option to build development version
  * Update translations
  * Add preference to disable CSP
  * Use CSP to block unsafe resources
  * Fix typo in README.md (#116)
  * Update Brazilian Portuguese translation (#113)
  * Update Russian translation (#112)
  * Update control
  * Fix dictionary not accessible if it's not the default action
  * Update French translation (#109)
  * Update Dutch translation (#108)
* Sun Jul  7 2019 dead_mozay@opensuse.org
- Update to version 1.4.0:
  * Update screenshots
  * Update translations again
  * Don't remember file if it wasn't successfully opened
  * Allow opening files from the error screen
  * Remove stack switcher padding
  * Update translations
  * Update README.md
  * Prepare for release
  * Fix popover positioning
  * Add selection action preference
  * Add footnote preference
  * Refactor cursor preference
  * Add preference to restore last file automatically
  * Add sidebar preference
  * Don't show footnote when there's no footnote
  * Use GtkStack in preference window
  * Fix not being able to toggle navbar when there's no navbar
  * Prevent selection when switching stack items
  * Fix stuff not working when starting with the reading progress bar hidden
  * Escape ampersands
  * Use Wikimedia REST API
  * Improve popover placement
  * Allow setting target language for Google Translate
  * Add Google Translate
  * Add Wikipedia lookup
  * Don't highlight or lookup on selection
  * Refactor popover
  * Set max width because some dictionaries don't wrap
  * Add default width to "About This Book" dialog
  * Update README.md
  * Update README.md
  * Add support for dictd
  * Remove trailing whitespaces
  * Farewell to Libsoup
  * Refactor dictionary lookup
  * Make font-weight override less agressive
  * Add list-{remove,add}-symbolic as fallback in accordance with SpinButton
  * Add backspace shortcut
  * Update README.md
  * Disable resize polling in Epub.js
  * Update Debian package specification
  * Add Debian package specification
  * Use sentence case for tooltip text
  * Add copyright notice
  * Make handling of ByteArrays compatible with older versions of GJS
  * Make things more compatible with older environments
  * Initial support for popup footnotes/endnotes
  * Remember sidebar page
  * Update README.md
  * Redraw annotations on view change
  * Add separators to notes and bookmarks list
  * Add page entry
  * Add tooltip to TOC items
  * Restore frame to search results
  * Add optional sidebar UI for TOC, bookmarks, and annotations
  * Refactor TOC, bookmarks, and annotations popover
  * Add option to search current chapter only
* Sat Jun 29 2019 dead_mozay@opensuse.org
- Update to version 1.3.1:
  * Remove unnecessary set_value call
  * Update Russian translation (#90)
  * Update Italian translation (#89)
  * Update Brazilian Portuguese translation (#84)
  * Update Russian translation (#83)
  * Updated Dutch translation (#82)
* Tue Jun 18 2019 dead_mozay@opensuse.org
- Update to version 1.3.0:
  * Update screenshot
  * Fix page divider not showing up when viewer width is 800
  * Update Spanish translation (#81)
  * Add Czech translation (#80)
  * Update French translation (#61)
  * Add GJS version requirement
  * Use font on font button
  * Allow setting font-style, because it's shown in the font chooser
  * Update translations
  * Add UI for adding and removing themes
  * Add support for auto-hiding cursor
  * Add shortcut for leaving fullscreen
  * Use const instead of let
  * Add shortcut for closing current window
  * Add shortcut for toggling reading progress bar
  * Handle selection on mouseup
  * Prefer opening annotation popover from the bottom
  * Add Indonesian translation (#72)
  * Prettify config JSON
  * Add UI for tweaking themes
* Thu Jun 13 2019 dead_mozay@opensuse.org
- Update to version 1.2.1:
  * Add Brazilian Portuguese translation (#70)
  * Add Spanish translation (#65)
  * Update Italian translation (#66)
  * Update Russian translation (#62)
  * Improve reading time estimate for CJK languages
  * Make step size smaller for font-size and spacing
  * Build fixes (#64)
  * Update translations
  * Add title to file chooser dialog
  * Fix gigantic spinner with some themes
  * Fix currentLocation.start being undefined sometimes
  * Add time left in chapter
  * Remove unnecessary rounding
  * Show time left in tooltip
  * Prevent page flip when zoomed
  * Add support for zooming and copying images
  * Update translations
  * Use plural form for margins label
  * More gettext workaround
  * Tweak brightness slider
  * Add brightness slider
  * Use theme colors to display book description
  * Make j and k scroll one line
  * Set shortcuts in more appropriate places
  * Use title case in menu
  * Update Italian translation (#57)
  * Update translations again
  * Add "Bookmark current location" to shortcuts window
  * Update translations
  * Add custom margin support
  * Inherit alignment instead of left when not justified
  * Add shortcut for quit
  * Show bookmark status on bookmarks button
  * Add French translation (#54)
  * Update Russian translation (#55)
  * Add support for custom themes
  * Add workaround for gettext bug
  * Fix error when switching locale
  * Updated Dutch translation (#51)
  * Finally fix some books not rendering sometimes
  * Apply justification to `p` only
  * Proper patch to fix image width
  * Update README.md
  * Update Italian translation (#50)
  * Add Fedora installation instructions (#39)
  * Update Russian translation (#48)
  * Fix book not rendering sometimes
* Thu Jun  6 2019 dead_mozay@opensuse.org
- Update to version 1.2.0:
  * Update screenshot
  * Update translations
  * Add instruction for enabling auto-hyphenation
  * Store generated locations in user cache dir instead of localStorage
* Wed Jun  5 2019 dead_mozay@opensuse.org
- Update to version 1.1.1:
  * Remove note from Void instructions (#47)
  * Add option to enable single page view
  * Add option for justification and hyphenation
  * Add hyphenation
  * Catch localStorage error
  * Improve 'use publisher font' mode
  * Update Russian translation (#33)
  * Add Void Linux instructions to Readme (#36)
* Mon Jun  3 2019 dead_mozay@opensuse.org
- Update Dutch translation (#31)
- Update Russian translation (#29)
* Sun Jun  2 2019 dead_mozay@opensuse.org
- Update to version 1.1.0:
  * Update README.md
  * Update translations
  * Fix opening files with would-be-percent-encoded characters
  * Update Russian translation (#25)
  * Prevent navigation from wheel event when zoomed in
  * Add option to disable dictionary lookup
  * Add option to hide the navbar
  * Improve scrolling and page navigation
  * Improve handling of wheel events
  * Improve shortcuts
  * Add Dutch translation (#16)
  * Fix opening files with percent-encoding in their name or path
  * Add even more aggressive overrides and a switch to disable custom font
* Sat Jun  1 2019 dead_mozay@opensuse.org
- Update to version 1.0.1:
  * Add Russian translation
  * Add Italian translation
  * Fix error screen misalignment
  * Update translations
  * Fix leftover from example project template
  * Build and run from source without installing, fixed markdown line breaks according to spec
  * Add AUR package links to README.md
  * Clarify gesture feature
  * Add more navigation shortcuts
  * Fix a regression that breaks layout switching
* Sat Jun  1 2019 Dead Mozay <dead-mozay@opensuse.org>
- Initial package
